==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name></name>
    <message>
        <source></source>
        <translatorcomment>Dutch translation for qtsmbstatus
Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
This file is distributed under the same license as the qtsmbstatus package.
FIRST AUTHOR &lt;EMAIL@ADDRESS&gt;, 2008.

</translatorcomment>
        <translation>Project-Id-Version: qtsmbstatus
Report-Msgid-Bugs-To: FULL NAME &lt;EMAIL@ADDRESS&gt;
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-09-24 14:10+0000
Last-Translator: Elco &lt;Unknown&gt;
Language-Team: Dutch &lt;nl@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Machine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Laat CIFS/SMB activitieten zien</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configureren</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Met dank aan:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Dit programma is gelicenseerd onder de termen van de GNU General Public License versie 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Tekst zoeken</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Tekst niet gevonden.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Gebruiker %1 heeft share %2 (%3) geopend</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Gebruiker %1 heeft bestand %2 (%3) geopend</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB activitieten</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Te versturen bericht</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Te versturen berciht naar %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Weet je zeker dat je de verbinding van gebruiker %1 wil verbreken ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nee</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Verzend bericht naar alle gebruikers</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Verzend bericht naar</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Verbinding gebruiker verbreken</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Een update is beschikbaar</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Een nieuwe versie van %1 is beschikbaar</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>U kunt hem hier dowloaden: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configureren</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Interval tussen smbstatus verzoeken in seconden, (interval &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Laat verborgen shares zien (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Laat verborgen shares zien</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notificaties en log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limiet log:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagen</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Laat icoon zien QtSmbstatus in de systeembalk</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Laat activiteiten zien in &quot;ballon berichten&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Status notificatie berichten</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Log SMB/CIFS activiteiten</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diversen</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatisch op updates controleren</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Een nieuwe versie is beschikbaar</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbinding</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standaard Gebruikersnaam:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Verbind automatisch bij het opstarten van qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Automatisch verbinden</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standaard host adres:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Gebruikersnaam (standaard:  gebruikersnaam = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Hostadres</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Verbinden / Verbinding verbreken</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Over QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Over QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Over Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configureer client</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configureer QtSmbstatus client</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Machine</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Zoek machine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Gebruiker</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Zoek gebruiker</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Share &amp;open</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Zoek share open</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Geblokkeerd bestand</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Zoek bestand open</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Volgende</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Vind volgende</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Tekst zoeken</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Sluit QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Laat CIFS/SMB activiteiten zien</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Verbi&amp;nden</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Laat Acitiviteiten Zien</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Log opslaan</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Bekijk / Verberg shares</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Bekijk / verberg bestanden</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Verbind naar qtsmbstatus server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>login</source>
        <translation>aanmelden</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>afsluiten</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Verbinding maken bezig op %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Verbonden met host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Verbinding verbroken</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbinding verbreken</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Ongeldig gebruikersnaam of wachtwoord !</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.0.orig.tar.gz: qtsmbstatus-2.2.0/client/tr/qtsmbstatus_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name></name>
    <message>
        <source></source>
        <translatorcomment>Dutch translation for qtsmbstatus
Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
This file is distributed under the same license as the qtsmbstatus package.
FIRST AUTHOR &lt;EMAIL@ADDRESS&gt;, 2008.

</translatorcomment>
        <translation>Project-Id-Version: qtsmbstatus
Report-Msgid-Bugs-To: FULL NAME &lt;EMAIL@ADDRESS&gt;
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-09-24 14:10+0000
Last-Translator: Elco &lt;Unknown&gt;
Language-Team: Dutch &lt;nl@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Machine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Gebruiker</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Laat CIFS/SMB activitieten zien</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configureren</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimaliseren</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Met dank aan:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Dit programma is gelicenseerd onder de termen van de GNU General Public License versie 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Tekst zoeken</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Tekst niet gevonden.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Gebruiker %1 heeft share %2 (%3) geopend</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Gebruiker %1 heeft bestand %2 (%3) geopend</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB activitieten</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Te versturen bericht</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Te versturen berciht naar %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Weet je zeker dat je de verbinding van gebruiker %1 wil verbreken ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nee</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Verzend bericht naar alle gebruikers</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Verzend bericht naar</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Verbinding gebruiker verbreken</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Een update is beschikbaar</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Een nieuwe versie van %1 is beschikbaar</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>U kunt hem hier dowloaden: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configureren</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Interval tussen smbstatus verzoeken in seconden, (interval &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Laat verborgen shares zien (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Laat verborgen shares zien</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notificaties en log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limiet log:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagen</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Laat icoon zien QtSmbstatus in de systeembalk</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Laat activiteiten zien in &quot;ballon berichten&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Status notificatie berichten</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Log SMB/CIFS activiteiten</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diversen</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatisch op updates controleren</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Een nieuwe versie is beschikbaar</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbinding</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standaard Gebruikersnaam:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Verbind automatisch bij het opstarten van qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Automatisch verbinden</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standaard host adres:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Gebruikersnaam (standaard:  gebruikersnaam = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Hostadres</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Verbinden / Verbinding verbreken</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Over QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Over QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Over Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configureer client</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configureer QtSmbstatus client</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Machine</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Zoek machine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Gebruiker</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Zoek gebruiker</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Share &amp;open</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Zoek share open</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Geblokkeerd bestand</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Zoek bestand open</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Volgende</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Vind volgende</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Tekst zoeken</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Sluit QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Laat CIFS/SMB activiteiten zien</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Verbi&amp;nden</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Laat Acitiviteiten Zien</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Log opslaan</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Bekijk / Verberg shares</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Bekijk / verberg bestanden</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Verbind naar qtsmbstatus server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>login</source>
        <translation>aanmelden</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>afsluiten</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Verbinding maken bezig op %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Verbonden met host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Verbinding verbroken</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Verbinding verbreken</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Ongeldig gebruikersnaam of wachtwoord !</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
